<p>
    Please confirm you would like to delete the following nodes and pages:

{{nodes|safe}}

</p>
{% if aliases %}
<p>
    The following aliased pages will also be removed:

{{aliases|safe}}
</p>
{% endif %}
