<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
    <title>{{page.title}}</title>
    <meta http-equiv="CACHE-CONTROL" CONTENT="NO-CACHE">
    {% comment %}
    <script type="text/JavaScript"
        src="http://ajax.googleapis.com/ajax/libs/jquery/1.7/jquery.min.js">
    </script>
    {% endcomment %}
    <script type="text/JavaScript" src="/static/yacon/js/jquery-1.7.2.min.js">
    </script>
    <script type="text/javascript" src="/static/yacon/ckeditor/ckeditor.js">
    </script>
    <script type="text/javascript" 
      src="/static/yacon/ckeditor/adapters/jquery.js"></script>
    <script type="text/javascript" src="/static/yacon/js/yacon/editable.js">
    </script>
</head>
<body>
    {% block body %}
    {% endblock body %}
</body>
</html>
