<div class="yacon_editable" id="block_{{block.id}}">
    <div class="yacon_ajax_error"></div>
    <div class="yacon_ajax_csrf">{{csrf_token}}</div>
    <div class="yacon_editable_content" contenteditable="false">
      {% if content %}
          {{content}}
      {% else %}
          <br/>
      {% endif %}
    </div>
    <div class="yacon_editable_buttons_group">
      <button class="yacon_editable_edit">
        {{button_text.content_edit_button}}
      </button>
      <button class="yacon_editable_done">
        {{button_text.content_save_button}}
      </button>
      <button class="yacon_editable_cancel">
        {{button_text.content_cancel_button}}
      </button>
    </div>
</div>
