/* nexus.css

Stye sheet for Nexus admin area in the Yacon project
*/

body {
    font-family: “Times New Roman”, Times, serif;
    font-size: 12pt;
    height: 100%;
    width: 100%;
    margin:0;
    padding:0;
}

#container {
    height: 100%;
    width: 100%;
    position:absolute;
}

#menu {
    height: 50px;
    width: 120px;
    position: absolute;
    top: 10px;
    right: 10px;
    z-index: 1;
    display:block;
}
#menu ul {
    list-style-type:none; 
    padding:0; 
    margin:0;
}
#menu li {
    display:block;
    float:right;
}
#menu a {
    color: #000;
}

#navbar {
    height: 50px;
    width: 100%;
}
#content {
    height: 600px;
}

/* One-Column View */
.inside {
    height:100%;
    padding-left: 6px;
}

/* Two-Column Views */
.right, .left {
    height:100%;
    float: left;
}
.left {
    min-width: 24%;
    max-width: 24%;
    padding-right: 1%;
}
.right {
    min-width: 50%;
    max-width: 70%;
}

#node_container {
    padding-left: 6px;
}

.toolbar {
    padding: 4px;
    height: 28px;
    font-size: 8pt;
}

#tree_container {
    height: 100%;
}

#site_sidebar {
    float: right;
}

#site_select_wrapper {
    font-size: 9pt;
    float: left;
}

.dialog_form_table th {
    padding: 10px 10px 5px 5px;
    vertical-align: middle;
}

#page_tree_container {
    height: 70%;
}
#tree {
}
#menu_tree_container {
    height: 30%;
}

.halfspace {
    height: 10px;
}

table {width:95%; border-top:1px solid #000; border-right:1px solid #000;
margin:1em auto; border-collapse:collapse;}
td { color:#678197; border-bottom:1px solid #000; border-left:1px solid #000;
padding: .3em; text-align:center; text-align:left}
td.centred {text-align:center}
tr.odd td { background:#fff;}
tr.even td { background:#ededed;}
th { background:#cecece; text-align:left; font-weight:bold; color: #000;
border-left:1px solid #000; border-bottom:1px solid #000; padding-left: .3em;
padding-top: .1em;}

th img {border:1px solid #cecece;}
img.selected {border:1px solid #000;}

#paginator {position:relative; width:400px; height:40px; font-size:16px; font-weight:bold}
#paginator a {color:#000;}

#paginator_prev {width:50px; position:absolute; left:0px;}
#paginator_next {width:50px; position:absolute; right:0px; text-align:right;}
#paginator_numbers {width:300px; position:absolute; left:50px; text-align:center;}

.paginator_elipses {letter-spacing:normal !important;}

/* jQuery UI Overrides */

/*
.ui-button.ui-widget .ui-button-text {
    font-size: x-small !important;
}
*/

