{% extends base_template %}

{% block scripts %}
    {{ block.super }}
    <!-- dynatree -->
    <link type="text/css" rel="stylesheet" 
        href="/static/yacon/js/dynatree/skin/ui.dynatree.css" />	
    <script type="text/JavaScript" 
      src="/static/yacon/js/dynatree/jquery.cookie.js"></script>
    <script type="text/JavaScript" 
        src="/static/yacon/js/dynatree/jquery.dynatree.min.js"></script>

    <script type="text/JavaScript" src="/static/yacon/js/yacon/tree.js">
    </script>
    <script type="text/JavaScript" 
      src="/static/yacon/js/yacon/browser/dialogs.js"></script>
    <script type="text/JavaScript" 
      src="/static/yacon/js/yacon/browser/setup.js"></script>

    <script type="text/JavaScript">
        $(document).ready(function(){
            if( "{{choose_mode}}" == "view" ) {
                $('#navbar').tabnav('select_by_id', 'nav_uploads');
            }
            setup();
        });
    </script>
{% endblock scripts %}

{% block content %}
<div class="left">
    {% if not popup %}
    <div class="toolbar ui-widget-header ui-corner-all">
        <div id="fake_toolbar"></div>
    </div>
    {% endif %}
    <div id="tree_container">
        <div id="tree">
        </div>
    </div>
</div>
<div class="right">
    <div id="node_container">
    </div>
</div>

<!-- Dialog Boxes -->
<div id="remove_folder_dialog">
</div>

<div id="add_folder_dialog">
    <p>
        Enter name of folder:
    </p>
    <form id="add_folder_form">
        <table class="dialog_form_table">
            <tr>
                <th> <label for="add_folder_name">Name</label> </th>
                <td> 
                    <input type="text" name="name" id="add_folder_name" /> 
                </td>
            </tr>
        </table>
    </form>
</div>
{% endblock content %}
