<div class="yacon_title_editable" id="page_{{page.id}}">
    <div class="yacon_editable_content">{{page.title}}</div>
    <div class="yacon_ajax_csrf">{{csrf_token}}</div>
    <button class="yacon_title_editable_edit">{{button_text.title_edit_button}}
    </button>
    <button class="yacon_title_editable_done">{{button_text.title_save_button}}
    </button>
    <button class="yacon_title_editable_cancel">
      {{button_text.title_cancel_button}}</button>
</div>
