    {% comment %}
        To be included in the "scripts" area of a template that is used to
        display, create or edit content
    {% endcomment %}

    <script type="text/javascript" src="/static/yacon/ckeditor/ckeditor.js">
    </script>
    <script type="text/javascript" 
      src="/static/yacon/js/yacon/content_utils.js"></script>
    {% if create_mode %}
        <script type="text/javascript" 
          src="/static/yacon/js/yacon/createable.js"></script>
    {% else %}
        <script type="text/javascript" src="/static/yacon/js/yacon/editable.js">
        </script>
    {% endif %}
