<div class="yacon_error">
{% block message %}
{% endblock message %}
<p>
The block was specified using the following details:
</p>
<table>
    <tr>
        <th>Template Tag</th>
        <td>{{tag_name}}</td>
    </tr>
    <tr>
        <th>Template Parameters</th>
        {% if tag_parameters %}
        <td>
            {% for key, value in tag_parameters.items %}
            {{key}}:{{value}}<br/>
            {% endfor %}
        <td>
        {% else %}
        <td><br/></td>
        {% endif %}
    </tr>
    <tr>
        <th>URI</th>
        <td>{{uri}}</td>
    </tr>
    <tr>
        <th>After Slugs</th>
        <td>{{page.after_slugs}}</td>
    </tr>
    <tr>
        <th>Page Title</th>
        <td>{{page.title}}</td>
    </tr>
    <tr>
        <th>Page Slug</th>
        <td>{{page.slug}}</td>
    </tr>
    <tr>
        <th>Page Metapage Alias</th>
        <td>{{page.metapage_alias}}</td>
    </tr>
    <tr>
        <th>Node ID</th>
        <td>{{page.metapage.node.id}}</td>
    </tr>
    <tr>
        <th>Page Type</th>
        <td>{{page.metapage.page_type.name}}</td>
    </tr>
    <tr>
        <th>Page Template</th>
        <td>{{page.metapage.page_type.template}}</td>
    </tr>
    <tr>
        <th>Block ID</th>
        <td>{{block.id}}</td>
    </tr>
    <tr>
        <th>Block Specifier Name</th>
        <td>{{block.block_type.name}}</td>
    </tr>
    <tr>
        <th>Block Content Handler</th>
        <td>{{block.block_type.content_handler_name}}</td>
    </tr>
    <tr>
        <th>Block Content Handler Parameters</th>
        <td>{{block.block_type.content_handler_parms}}</td>
    </tr>
    <tr>
        <th>Block Parameters</th>
        <td>{{block.parameters}}</td>
    </tr>
</table>
</div>
